Fix unit test

Now that scale is gone, reading should match the value
written.

Change-Id: I63a3ec0dc50ee5eacc08b23d0669fa065961abd2
Signed-off-by: James Feist <james.feist@linux.intel.com>
diff --git a/test/helpers.hpp b/test/helpers.hpp
index 6952c52..b95200c 100644
--- a/test/helpers.hpp
+++ b/test/helpers.hpp
@@ -32,11 +32,11 @@
  * @param[in] path - the dbus path passed to the object
  * @param[in] intf - the dbus interface
  * @param[in] properties - an ordered list of expected property updates.
  * @param[in] index - a pointer to a valid integer in a surviving scope.
  */
 void SetupDbusObject(sdbusplus::SdBusMock* sdbus_mock, bool defer,
                      const std::string& path, const std::string& intf,
-                     const std::vector<std::string>& properties, int* index)
+                     const std::vector<std::string>& properties, double* index)
 {
     EXPECT_CALL(*sdbus_mock,
                 sd_bus_add_object_vtable(IsNull(), NotNull(), StrEq(path),
@@ -32,11 +32,11 @@
  * @param[in] intf - the dbus interface
  * @param[in] properties - an ordered list of expected property updates.
- * @param[in] index - a pointer to a valid integer in a surviving scope.
+ * @param[in] index - a pointer to a valid double in a surviving scope.
  */
 void SetupDbusObject(sdbusplus::SdBusMock* sdbus_mock, bool defer,